summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmboundedbyedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmboundedbyedit.h')
-rw-r--r--kpovmodeler/pmboundedbyedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmboundedbyedit.h b/kpovmodeler/pmboundedbyedit.h
index f575fbb8..ce01d98d 100644
--- a/kpovmodeler/pmboundedbyedit.h
+++ b/kpovmodeler/pmboundedbyedit.h
@@ -39,9 +39,9 @@ class PMBoundedByEdit : public PMDialogEditBase
typedef PMDialogEditBase Base;
public:
/**
* Creates a PMBoundedByEdit with tqparent and name
*/
- PMBoundedByEdit( TQWidget* tqparent, const char* name = 0 );
+ PMBoundedByEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -39,9 +39,9 @@ class PMBoundedByEdit : public PMDialogEditBase
public:
/**
- * Creates a PMBoundedByEdit with tqparent and name
+ * Creates a PMBoundedByEdit with parent and name
*/